# snipsearch

Python package to search multiple strings within Python snippets.

## Install

pip install snipsearch

## Usage

snipsearch [-h] [-n N] searchdir searchterm1 searchterm2 ...

Find code snippets which are most related to search keywords.

positional arguments:\
* searchdir\
    * Directory containing Python (.py) files to search through\
* searchterms\
    * List as many strings as you would like to search for (all equally weighted)

optional arguments:\
* -h, --help\
    * show this help message and exit\
* -n N, -number N\
    * Number of code snippet results to print

## Read The Docs

Download "docs" folder or check [preview](https://htmlpreview.github.io/?https://github.com/jkrist2696/snipsearch/blob/main/docs/index.html).

## Contributing

Message me on Github.

## License

[GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)

## Copyright:

(c) 2023, Jason Krist